Module: Benchmark
- Defined in:
- lib/benchmark/inputs.rb,
lib/benchmark/inputs/version.rb
Defined Under Namespace
Modules: Inputs
Class Method Summary collapse
-
.inputs(values, **options) {|job| ... } ⇒ Benchmark::Inputs::Job
Initializes a benchmark job with the given inputs and yields that job to the given block.
Class Method Details
.inputs(values, **options) {|job| ... } ⇒ Benchmark::Inputs::Job
Initializes a benchmark job with the given inputs and yields that job to the given block.
41 42 43 44 45 |
# File 'lib/benchmark/inputs.rb', line 41 def self.inputs(values, **) job = Inputs::Job.new(values, ) yield job job end |