Class: Benchmark::Inputs::Report
- Inherits:
-
Object
- Object
- Benchmark::Inputs::Report
- Defined in:
- lib/benchmark/inputs.rb
Instance Attribute Summary collapse
-
#label ⇒ String
readonly
The label for the report.
-
#ratio ⇒ Float?
readonly
The ratio of iterations per second for this report compared to the fastest report.
Instance Method Summary collapse
-
#ips ⇒ Float
The estimated iterations per second for the report.
-
#stddev ⇒ Float
The #ips standard deviation.
Instance Attribute Details
#label ⇒ String (readonly)
The label for the report.
211 212 213 |
# File 'lib/benchmark/inputs.rb', line 211 def label @label end |
#ratio ⇒ Float? (readonly)
The ratio of iterations per second for this report compared to the fastest report. Will be nil if the difference between the two falls within the combined measurement error.
This value is set by Job#compare!.
220 221 222 |
# File 'lib/benchmark/inputs.rb', line 220 def ratio @ratio end |
Instance Method Details
#ips ⇒ Float
The estimated iterations per second for the report.
249 250 251 |
# File 'lib/benchmark/inputs.rb', line 249 def ips @mean end |
#stddev ⇒ Float
The #ips standard deviation.
256 257 258 |
# File 'lib/benchmark/inputs.rb', line 256 def stddev @stddev ||= @n < 2 ? 0.0 : Math.sqrt(@m2 / (@n - 1)) end |